@@ -32,11 +32,9 @@ sPlotSpectra <- function(spectra, pca, pc = 1, tol = 0.05,
 	ans <- data.frame(cov = cv, corr = crr)
 
 	title = paste(title, ": ", "s-Plot", sep = "")		
-	xrange <- range(cv)*c(1.0, 1.05) # makes room for labels
-	yrange <- range(crr)*c(1.0, 1.05)
 
 	plot(cv, crr, main = title, xlab = "covariance", ylab = "correlation",
-		pch = 20, xlim = xrange, ylim = yrange, ...)
+		pch = 20, ...)
 	abline(v = 0.0, col = "red")
 	abline(h = 0.0, col = "red")
 	legend("bottomright", y = NULL, pca$method, bty = "n", cex = 0.75)
